{-# LANGUAGE GeneralizedNewtypeDeriving #-}

{-|
Module      : Network.Telnet.LibTelnet.Options
Description : Constants for option codes
Copyright   : (c) 2017-2021 Jack Kelly
License     : GPL-3.0-or-later
Maintainer  : jack@jackkelly.name
Stability   : experimental
Portability : non-portable

Telnet option codes. Many of these are defined in their own RFC.
<http://www.omnifarious.org/~hopper/technical/telnet-rfc.html> is a
good index of known options.
-}

module Network.Telnet.LibTelnet.Options
  ( Option(..)
  , optBinary
  , optEcho
  , optRCP
  , optSGA
  , optNAMS
  , optStatus
  , optTM
  , optRCTE
  , optNAOL
  , optNAOP
  , optNAOCRD
  , optNAOHTS
  , optNAOHTD
  , optNAOFFD
  , optNAOVTS
  , optNAOVTD
  , optNAOLFD
  , optXASCII
  , optLogout
  , optBM
  , optDET
  , optSUPDUP
  , optSUPDUPOutput
  , optSNDLOC
  , optTType
  , optEOR
  , optTUID
  , optOUTMRK
  , optTTYLOC
  , opt3270Regime
  , optX3Pad
  , optNAWS
  , optTSpeed
  , optLFlow
  , optLineMode
  , optXDISPLOC
  , optEnviron
  , optAuthentication
  , optEncrypt
  , optNewEnviron
  , optMSSP
  , optCompress2
  , optZMP
  , optEXOPL
  , optMCCP2
  ) where

import Foreign (Storable)
import Foreign.C (CUChar)

#include <libtelnet.h>

-- | Wrapper for telnet option codes.
newtype Option = Option { unOption :: CUChar } deriving (Eq, Show, Storable)
#{enum Option, Option
 , optBinary = TELNET_TELOPT_BINARY
 , optEcho = TELNET_TELOPT_ECHO
 , optRCP = TELNET_TELOPT_RCP
 , optSGA = TELNET_TELOPT_SGA
 , optNAMS = TELNET_TELOPT_NAMS
 , optStatus = TELNET_TELOPT_STATUS
 , optTM = TELNET_TELOPT_TM
 , optRCTE = TELNET_TELOPT_RCTE
 , optNAOL = TELNET_TELOPT_NAOL
 , optNAOP = TELNET_TELOPT_NAOP
 , optNAOCRD = TELNET_TELOPT_NAOCRD
 , optNAOHTS = TELNET_TELOPT_NAOHTS
 , optNAOHTD = TELNET_TELOPT_NAOHTD
 , optNAOFFD = TELNET_TELOPT_NAOFFD
 , optNAOVTS = TELNET_TELOPT_NAOVTS
 , optNAOVTD = TELNET_TELOPT_NAOVTD
 , optNAOLFD = TELNET_TELOPT_NAOLFD
 , optXASCII = TELNET_TELOPT_XASCII
 , optLogout = TELNET_TELOPT_LOGOUT
 , optBM = TELNET_TELOPT_BM
 , optDET = TELNET_TELOPT_DET
 , optSUPDUP = TELNET_TELOPT_SUPDUP
 , optSUPDUPOutput = TELNET_TELOPT_SUPDUPOUTPUT
 , optSNDLOC = TELNET_TELOPT_SNDLOC
 , optTType = TELNET_TELOPT_TTYPE
 , optEOR = TELNET_TELOPT_EOR
 , optTUID = TELNET_TELOPT_TUID
 , optOUTMRK = TELNET_TELOPT_OUTMRK
 , optTTYLOC = TELNET_TELOPT_TTYLOC
 , opt3270Regime = TELNET_TELOPT_3270REGIME
 , optX3Pad = TELNET_TELOPT_X3PAD
 , optNAWS = TELNET_TELOPT_NAWS
 , optTSpeed = TELNET_TELOPT_TSPEED
 , optLFlow = TELNET_TELOPT_LFLOW
 , optLineMode = TELNET_TELOPT_LINEMODE
 , optXDISPLOC = TELNET_TELOPT_XDISPLOC
 , optEnviron = TELNET_TELOPT_ENVIRON
 , optAuthentication = TELNET_TELOPT_AUTHENTICATION
 , optEncrypt = TELNET_TELOPT_ENCRYPT
 , optNewEnviron = TELNET_TELOPT_NEW_ENVIRON
 , optMSSP = TELNET_TELOPT_MSSP
 , optCompress2 = TELNET_TELOPT_COMPRESS2
 , optZMP = TELNET_TELOPT_ZMP
 , optEXOPL = TELNET_TELOPT_EXOPL
 , optMCCP2 = TELNET_TELOPT_MCCP2
 }
